@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::APIAccess;
-$Net::Kubernetes::Role::APIAccess::VERSION = '0.04';
+$Net::Kubernetes::Role::APIAccess::VERSION = '0.05';
 use Moose::Role;
 require LWP::UserAgent;
 require HTTP::Request;
@@ -13,7 +13,7 @@ Net::Kubernetes::Role::APIAccess
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =cut
 
@@ -29,7 +29,7 @@ has base_path => (
 	is       => 'ro',
 	isa      => 'Str',
 	required => 1,
-	default  => 'api/v1beta3',
+	default  => '/api/v1beta3',
 );
 
 has password => (
@@ -87,7 +87,7 @@ around BUILDARGS => sub {
 
 sub path {
 	my($self) = @_;
-	return $self->url.'/'.$self->base_path;
+	return $self->url.$self->base_path;
 }
 
 sub _build_lwp_agent {
